@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 **************
 Adjacency List
@@ -22,26 +21,14 @@ adjacency list (anything following the # in a line is a comment)::
      a b c # source target target
      d e
 """
-__author__ = '\n'.join(['Aric Hagberg <hagberg@lanl.gov>',
-                        'Dan Schult <dschult@colgate.edu>',
-                        'Loïc Séguin-C. <loicseguin@gmail.com>'])
-#    Copyright (C) 2004-2019 by
-#    Aric Hagberg <hagberg@lanl.gov>
-#    Dan Schult <dschult@colgate.edu>
-#    Pieter Swart <swart@lanl.gov>
-#    All rights reserved.
-#    BSD license.
 
-__all__ = ['generate_adjlist',
-           'write_adjlist',
-           'parse_adjlist',
-           'read_adjlist']
+__all__ = ["generate_adjlist", "write_adjlist", "parse_adjlist", "read_adjlist"]
 
-from networkx.utils import make_str, open_file
 import networkx as nx
+from networkx.utils import open_file
 
 
-def generate_adjlist(G, delimiter=' '):
+def generate_adjlist(G, delimiter=" "):
     """Generate a single line of the graph G in adjacency list format.
 
     Parameters
@@ -77,22 +64,22 @@ def generate_adjlist(G, delimiter=' '):
     directed = G.is_directed()
     seen = set()
     for s, nbrs in G.adjacency():
-        line = make_str(s) + delimiter
+        line = str(s) + delimiter
         for t, data in nbrs.items():
             if not directed and t in seen:
                 continue
             if G.is_multigraph():
                 for d in data.values():
-                    line += make_str(t) + delimiter
+                    line += str(t) + delimiter
             else:
-                line += make_str(t) + delimiter
+                line += str(t) + delimiter
         if not directed:
             seen.add(s)
-        yield line[:-len(delimiter)]
+        yield line[: -len(delimiter)]
 
 
-@open_file(1, mode='wb')
-def write_adjlist(G, path, comments="#", delimiter=' ', encoding='utf-8'):
+@open_file(1, mode="wb")
+def write_adjlist(G, path, comments="#", delimiter=" ", encoding="utf-8"):
     """Write graph G in single-line adjacency-list format to path.
 
 
@@ -115,13 +102,13 @@ def write_adjlist(G, path, comments="#", delimiter=' ', encoding='utf-8'):
 
     Examples
     --------
-    >>> G=nx.path_graph(4)
-    >>> nx.write_adjlist(G,"test.adjlist")
+    >>> G = nx.path_graph(4)
+    >>> nx.write_adjlist(G, "test.adjlist")
 
     The path can be a filehandle or a string with the name of the file. If a
     filehandle is provided, it has to be opened in 'wb' mode.
 
-    >>> fh=open("test.adjlist",'wb')
+    >>> fh = open("test.adjlist", "wb")
     >>> nx.write_adjlist(G, fh)
 
     Notes
@@ -134,19 +121,25 @@ def write_adjlist(G, path, comments="#", delimiter=' ', encoding='utf-8'):
     """
     import sys
     import time
-    pargs = comments + " ".join(sys.argv) + '\n'
-    header = (pargs
-              + comments + " GMT {}\n".format(time.asctime(time.gmtime()))
-              + comments + " {}\n".format(G.name))
+
+    pargs = comments + " ".join(sys.argv) + "\n"
+    header = (
+        pargs
+        + comments
+        + f" GMT {time.asctime(time.gmtime())}\n"
+        + comments
+        + f" {G.name}\n"
+    )
     path.write(header.encode(encoding))
 
     for line in generate_adjlist(G, delimiter):
-        line += '\n'
+        line += "\n"
         path.write(line.encode(encoding))
 
 
-def parse_adjlist(lines, comments='#', delimiter=None,
-                  create_using=None, nodetype=None):
+def parse_adjlist(
+    lines, comments="#", delimiter=None, create_using=None, nodetype=None
+):
     """Parse lines of a graph adjacency list representation.
 
     Parameters
@@ -173,11 +166,7 @@ def parse_adjlist(lines, comments='#', delimiter=None,
 
     Examples
     --------
-    >>> lines = ['1 2 5',
-    ...          '2 3 4',
-    ...          '3 5',
-    ...          '4',
-    ...          '5']
+    >>> lines = ["1 2 5", "2 3 4", "3 5", "4", "5"]
     >>> G = nx.parse_adjlist(lines, nodetype=int)
     >>> nodes = [1, 2, 3, 4, 5]
     >>> all(node in G for node in nodes)
@@ -204,23 +193,31 @@ def parse_adjlist(lines, comments='#', delimiter=None,
         if nodetype is not None:
             try:
                 u = nodetype(u)
-            except:
-                raise TypeError("Failed to convert node ({}) to type {}"
-                                .format(u, nodetype))
+            except BaseException as err:
+                raise TypeError(
+                    f"Failed to convert node ({u}) to type " f"{nodetype}"
+                ) from err
         G.add_node(u)
         if nodetype is not None:
             try:
-                vlist = map(nodetype, vlist)
-            except:
-                raise TypeError("Failed to convert nodes ({}) to type {}"
-                                .format(','.join(vlist), nodetype))
+                vlist = list(map(nodetype, vlist))
+            except BaseException as err:
+                raise TypeError(
+                    f"Failed to convert nodes ({','.join(vlist)}) to type {nodetype}"
+                ) from err
         G.add_edges_from([(u, v) for v in vlist])
     return G
 
 
-@open_file(0, mode='rb')
-def read_adjlist(path, comments="#", delimiter=None, create_using=None,
-                 nodetype=None, encoding='utf-8'):
+@open_file(0, mode="rb")
+def read_adjlist(
+    path,
+    comments="#",
+    delimiter=None,
+    create_using=None,
+    nodetype=None,
+    encoding="utf-8",
+):
     """Read graph in adjacency list format from path.
 
     Parameters
@@ -248,26 +245,26 @@ def read_adjlist(path, comments="#", delimiter=None, create_using=None,
 
     Examples
     --------
-    >>> G=nx.path_graph(4)
+    >>> G = nx.path_graph(4)
     >>> nx.write_adjlist(G, "test.adjlist")
-    >>> G=nx.read_adjlist("test.adjlist")
+    >>> G = nx.read_adjlist("test.adjlist")
 
     The path can be a filehandle or a string with the name of the file. If a
     filehandle is provided, it has to be opened in 'rb' mode.
 
-    >>> fh=open("test.adjlist", 'rb')
-    >>> G=nx.read_adjlist(fh)
+    >>> fh = open("test.adjlist", "rb")
+    >>> G = nx.read_adjlist(fh)
 
     Filenames ending in .gz or .bz2 will be compressed.
 
-    >>> nx.write_adjlist(G,"test.adjlist.gz")
-    >>> G=nx.read_adjlist("test.adjlist.gz")
+    >>> nx.write_adjlist(G, "test.adjlist.gz")
+    >>> G = nx.read_adjlist("test.adjlist.gz")
 
     The optional nodetype is a function to convert node strings to nodetype.
 
     For example
 
-    >>> G=nx.read_adjlist("test.adjlist", nodetype=int)
+    >>> G = nx.read_adjlist("test.adjlist", nodetype=int)
 
     will attempt to convert all nodes to integer type.
 
@@ -278,7 +275,7 @@ def read_adjlist(path, comments="#", delimiter=None, create_using=None,
     created.  The default is `nx.Graph`, an undirected graph.
     To read the data as a directed graph use
 
-    >>> G=nx.read_adjlist("test.adjlist", create_using=nx.DiGraph)
+    >>> G = nx.read_adjlist("test.adjlist", create_using=nx.DiGraph)
 
     Notes
     -----
@@ -289,16 +286,10 @@ def read_adjlist(path, comments="#", delimiter=None, create_using=None,
     write_adjlist
     """
     lines = (line.decode(encoding) for line in path)
-    return parse_adjlist(lines,
-                         comments=comments,
-                         delimiter=delimiter,
-                         create_using=create_using,
-                         nodetype=nodetype)
-
-
-# fixture for pytest
-def teardown_module(module):
-    import os
-    for fname in ['test.adjlist', 'test.adjlist.gz']:
-        if os.path.isfile(fname):
-            os.unlink(fname)
+    return parse_adjlist(
+        lines,
+        comments=comments,
+        delimiter=delimiter,
+        create_using=create_using,
+        nodetype=nodetype,
+    )
